---
title: 결제대행사 계약절차
category: 포트원 이용절차 (온보딩 가이드) > 전자결제 신청 > 결제대행사 계약안내
seo:
  title: 결제대행사 계약절차
  description: >-
    포트원 전자결제 신청을 위한 안내입니다. 전자결제 신청 후 계약은 PG사와 진행되기에, 진행 전에 포트원이 제공하는 결제대행사별 안내
    경로 및 특징 정보를 확인하시기 바랍니다.
  keywords:
    - 이용절차
    - PG사
    - PG사 계약안내
    - 계약안내
    - 결제대행사
    - 결제대행사 계약안내
tags:
  - 공통
  - PG계약
  - 가입신청
  - 계약서작성
pgCompanies:
  - 공통
searchTags:
  - 결제대행사
  - 전자결제신청
  - 가입신청
  - PG사별계약안내방법
  - 미리준비하기
  - PG계약절차
---

<Callout content="포트원을 통한 PG사 계약 절차를 안내해드립니다.
전자결제 신청 이후 앞으로의 계약은 PG 사와 진행하시게 됩니다. 포트원 관리자콘솔에서 ‘담당자 이메일’ 항목에 입력하신 메일 주소로 다음 절차를 안내드리고 있으니 메일을 주기적으로 체크해 주시기 바랍니다." icon="" />

### **결제대행사별 안내 경로**

가입신청까지 모두 완료되었다면 다음 단계부터는 결제대행사로부터 안내를 받습니다.

신청 이후 다음 단계부터는 결제대행사별로 진행 절차가 조금씩 상이한데요, 결제대행사에 따라 포트원에서 먼저 안내를 드리기도 하며 결제대행사에서 직접 메일로 안내를 드리기도 합니다.

기본적으로 모든 안내는 메일로 확인해주시기 바라며 종종 **스팸함**으로 누락되는 경우도 있으니 유의하여 진행상황을 체크해주시기 바랍니다.

<Callout title="결제대행사별 계약절차 보러가기↗︎" />

### **결제대행사별 특징 알고 가기**

결제대행사에서 제공되는 서비스는 각 결제대행사별 정책에 따라 조금씩 다른 차이점이 존재하는데요, 미리 알아두면 좋을 결제대행사별 특징을 모아두었으니 이용하실 결제대행사에 맞춰 필요한 정보를 확인하시기 바랍니다.

<Callout title="결제대행사별 서비스 특징 보러가기↗︎" />
